%% input -------------------------------------------
% xUL_f2d input for Nd=2 dimensional system
%
% input
% - flow model definition
%    dxdt_fnc
%   * for Rankine vortex
%       f0(Nv*Nd):       IC of the 2f flow
%       dxdt_prm.Nv:     number of rankine vortives
%       dxdt_prm.Gv:     Circulation of individual vortex
%       dxdt_prm.Rv2:    (radius)^2C of individual vortex
%       dxdt_prm.ixU_v: starting id for individual vortex
%
% - for Lagragian analysis
%   * x and U for individual particles
%       xgrd(nd).mn       MN of x grid for nd=1:Nd
%       xgrd(nd).mx       MX of x grid for nd=1:Nd
%       xgrd(nd).n        no of x grid for nd=1:Nd
%   * two analyses
%    (i)  (t0,   t0_tau) fixed t0, varying tau0
%    (ii) (t_tau0, tau0) varying t, fixed tau0
%
% - for output
%        dnm_op.bsc:      basic op directory
%        dnm_op.bfnc:     basic-model func directory
%        dnm_op.bfcs:     basic-model func-case directory
%
% - for plot
%       plt_prm.Ucaxs:    caxis for U
%       plt_prm.Lcaxs:    caxis for L
%       plt_prm.Lcof:     cut off for L
%       plt_prm.avi_fps:  fps for avi movie
%       plt_prm.Lcof:     color map
%
% 15 Summer: Kayo Ide
%
%--------------------------------------------------
% x and U=M/tau
%- grd: spatial resoluion of output 
Np=1;
nd=1; xgrd(nd).mn=-3; xgrd(nd).mx=3; xgrd(nd).n=601; Np=Np*xgrd(nd).n;
nd=2; xgrd(nd).mn=-3; xgrd(nd).mx=3; xgrd(nd).n=601; Np=Np*xgrd(nd).n; 
% U=M/tau computation
%- t0tau
t0=0;
t0_tau=[0:0.1:2];
%- ttau0
t_tau0=[0:0.1:3]; 
tau0=1;
% flow
%- initialization
Nv=0;
Nv=Nv+1; flw0(Nv).xv=[-1 0];
Nv=Nv+1; flw0(Nv).xv=[0.8  0];
Nv=Nv+1; flw0(Nv).xv=[0.  0.5];
f0=[];
for nd=1:Nd;
    for nv=1:Nv; f0=[f0; flw0(nv).xv(:,nd)]; end; 
end
%- function name
dxdt_fnc=@xUL_f2d_dxdt_rv;
%- parameters
dxdt_prm.Nv=Nv; 
dxdt_prm.Gv=1*ones(1,dxdt_prm.Nv); 
dxdt_prm.Rv2=(0.1^2)*ones(1,dxdt_prm.Nv);
dxdt_prm.ixMf_v=(Nd+1)*Np+[0 Nv];

%%  output directory 
cprm=['_Nv' int2str(dxdt_prm.Nv) 'G'];
for nv=1:Nv; cprm=[cprm num2str(dxdt_prm.Gv(nv))]; end
cprm=[cprm 'R'];  
for nv=1:Nv; cprm=[cprm num2str(sqrt(dxdt_prm.Rv2(nv)))]; end
dnm_op.bsc=['op'];
dnm_op.bfnc=[dnm_op.bsc '/xUL_f2d_' cnm.mdl];
dnm_op.bfcs=[dnm_op.bfnc '/' cnm.mdl cprm];

%% plot parameters
plt_prm.Ucaxs=[1 10];
plt_prm.Lcaxs=[1 20];
plt_prm.Lcof=8.5; % for t0tau
plt_prm.avi_fps=2;
plt_prm.cmp='jet';
